@@ -63,14 +63,11 @@ class Opinum(object):
         oauth.close()
         return self.token
     
-    def var(self, site, source, name=None, variable=None):
-        if name is None:
-            if variable is None: return -1
-            name = variable
+    def var(self, site, source, variable):
         try:
             return [
                 ts['id'] for ts in self.timeseries 
-                if all((ts['site'] == site, ts['source'] == source, ts['name'] == name))
+                if all((ts['site'] == site, ts['source'] == source, ts['name'] == variable))
             ][0]
         except:
             return -1
@@ -106,12 +103,9 @@ class Opinum(object):
         return resp
     
     @token_required
-    def get_ts(self, site, source, name=None, variable=None, interval=None):
-        if name is None: 
-            if variable is None: return []
-            name = variable
+    def get_dps(self, site, source, variable, interval=None):
         params = {
-            'filter.variableId': self.var(site, source, name),
+            'filter.variableId': self.var(site, source, variable),
             'filter.displayLevel': 'ValueVariableDate',
             'filter.includeToBoundary': True
         }
@@ -125,9 +119,9 @@ class Opinum(object):
             return []
         
     @token_required
-    def get_dps(self, site, source, variable, interval=None):
+    def get_ts(self, site, source, variable, interval=None):
         try:
-            data = self.get_ts(site, source, variable=variable, interval=interval)
+            data = self.get_dps(site, source, variable=variable, interval=interval)
             dps = pd.DataFrame(data)
             dps = dps.sort_values(by="date")
             dps.index = pd.to_datetime(dps["date"], format=iso)
@@ -138,21 +132,18 @@ class Opinum(object):
         
     
     @token_required
-    def push_ts(self, site, source, name=None, variable=None, dps=[]):
-        if name is None: 
-            if variable is None: return []
-            name = variable
-        logging.info(f"Opinum Datahub : pushing {len(dps)} datapoints to ({site}, {source}, {name}) ...")
+    def push_dps(self, site, source, variable, dps=[]):
+        logging.info(f"Opinum Datahub : pushing {len(dps)} datapoints to ({site}, {source}, {variable}) ...")
         return self.push([{
-            'variableId': self.var(site, source, name), 
+            'variableId': self.var(site, source, variable), 
             'data': dps
         }])
     
     @token_required
-    def push_dps(self, site, source, variable, dps=None):
+    def push_ts(self, site, source, variable, dps=None):
         try: 
             data = pd.DataFrame({ "date": dps.index.values, "value": dps.values })
             data["date"] = data["date"].dt.strftime(iso)
             data = data.to_dict(orient="records")
-            return self.push_ts(site, source, variable=variable, dps=data)
+            return self.push_dps(site, source, variable=variable, dps=data)
         except: return
\ No newline at end of file
